@@ -1,3 +1,4 @@
+/* $EPIC: queue.c,v 1.10 2003/07/09 21:10:25 jnelson Exp $ */
 /*
  *  queue.c - The queue command
  *
@@ -7,9 +8,33 @@
  *  Syntax:  /QUEUE -DO -LIST -NO_FLUSH -DELETE -FLUSH <name>
  *  Syntax:  /QUEUE <name> <commands>
  *
- *  Written by Jeremy Nelson
- *  Copyright 1993 Jeremy Nelson
- *  See the COPYRIGHT file for more information
+ * Copyright  1993, 2002 EPIC Software Labs.
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notices, the above paragraph (the one permitting redistribution),
+ *    this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 3. The names of the author(s) may not be used to endorse or promote
+ *    products derived from this software without specific prior written
+ *    permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+ * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+ * IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+ * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+ * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
+ * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
+ * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
  */
 
 #include "irc.h"
@@ -268,7 +293,7 @@ static void	add_queue (Queue **list, const char *name)
 	newq = (Queue *)new_malloc(sizeof(Queue));
 	newq->next = NULL;
 	newq->first = NULL;
-	newq->name = m_strdup(name);
+	newq->name = malloc_strdup(name);
 
 	for (q = *list; q && q->next; q = q->next)
 		;
@@ -339,8 +364,8 @@ static int	add_to_queue (Queue **list, const char *name, const char *what, const
 	}
 
 	c = (CmdList *)new_malloc(sizeof(CmdList));
-	c->what = m_strdup(what);
-	c->subargs = m_strdup(subargs);
+	c->what = malloc_strdup(what);
+	c->subargs = malloc_strdup(subargs);
 	c->next = NULL;
 
 	if (!q->first)
@@ -367,7 +392,10 @@ static void	delete_from_queue (Queue **list, const char *name, int which)
 		return;
 	}
 
-	if (which == 0 || !q->first) {
+	if (which == -1) {
+		say("QUEUE: You need to specify an entry to delete");
+		return;
+	} else if (which == 0 || !q->first) {
 		return;
 	} else if (which == 1) {
 		c = q->first;
